@@ -5,12 +5,16 @@ pages = [{
     "limit_find": [{'seo': u'imghp?hl=en&tab=wi', 'text': u'Images', u'href': u'http://www.google.com/imghp?hl=en&tab=wi', u'class': [u'gb1']}, {'seo': u'maps?hl=en&tab=wl', 'text': u'Maps', u'href': u'http://maps.google.com/maps?hl=en&tab=wl', u'class': [u'gb1']}, {'seo': u'?hl=en&tab=w8', 'text': u'Play', u'href': u'https://play.google.com/?hl=en&tab=w8', u'class': [u'gb1']}, {'seo': u'?tab=w1', 'text': u'YouTube', u'href': u'http://www.youtube.com/?tab=w1', u'class': [u'gb1']}, {'seo': u'nwshp?hl=en&tab=wn', 'text': u'News', u'href': u'http://news.google.com/nwshp?hl=en&tab=wn', u'class': [u'gb1']}],
     "limit_reverse_find": [{'href': '/intl/en/policies/', 'seo': '', 'text': 'Privacy & Terms'}, {'href': '/intl/en/about.html', 'seo': 'about.html', 'text': 'About Google'}, {'href': 'https://plus.google.com/116899029375914044550', 'seo': '116899029375914044550', 'text': '+Google', 'rel': ['publisher']}, {'href': '/services/', 'seo': '', 'text': 'Business Solutions'}, {u'href': u'/intl/en/ads/', 'seo': '', 'text': u'Advertising\xa0Programs'}],
     "limit_sort_text": [{'seo': u'imghp?hl=en&tab=wi', 'text': u'Images', u'href': u'http://www.google.com/imghp?hl=en&tab=wi', u'class': [u'gb1']}, {'seo': u'maps?hl=en&tab=wl', 'text': u'Maps', u'href': u'http://maps.google.com/maps?hl=en&tab=wl', u'class': [u'gb1']}, {'seo': u'nwshp?hl=en&tab=wn', 'text': u'News', u'href': u'http://news.google.com/nwshp?hl=en&tab=wn', u'class': [u'gb1']}, {'seo': u'?hl=en&tab=w8', 'text': u'Play', u'href': u'https://play.google.com/?hl=en&tab=w8', u'class': [u'gb1']}, {'seo': u'?tab=w1', 'text': u'YouTube', u'href': u'http://www.youtube.com/?tab=w1', u'class': [u'gb1']}],
-    "limit_sort_href": [{'seo': u'maps?hl=en&tab=wl', 'text': u'Maps', u'href': u'http://maps.google.com/maps?hl=en&tab=wl', u'class': [u'gb1']}, {'seo': u'nwshp?hl=en&tab=wn', 'text': u'News', u'href': u'http://news.google.com/nwshp?hl=en&tab=wn', u'class': [u'gb1']}, {'seo': u'imghp?hl=en&tab=wi', 'text': u'Images', u'href': u'http://www.google.com/imghp?hl=en&tab=wi', u'class': [u'gb1']}, {'seo': u'?tab=w1', 'text': u'YouTube', u'href': u'http://www.youtube.com/?tab=w1', u'class': [u'gb1']}, {'seo': u'?hl=en&tab=w8', 'text': u'Play', u'href': u'https://play.google.com/?hl=en&tab=w8', u'class': [u'gb1']}]
+    "limit_sort_href": [{'seo': u'maps?hl=en&tab=wl', 'text': u'Maps', u'href': u'http://maps.google.com/maps?hl=en&tab=wl', u'class': [u'gb1']}, {'seo': u'nwshp?hl=en&tab=wn', 'text': u'News', u'href': u'http://news.google.com/nwshp?hl=en&tab=wn', u'class': [u'gb1']}, {'seo': u'imghp?hl=en&tab=wi', 'text': u'Images', u'href': u'http://www.google.com/imghp?hl=en&tab=wi', u'class': [u'gb1']}, {'seo': u'?tab=w1', 'text': u'YouTube', u'href': u'http://www.youtube.com/?tab=w1', u'class': [u'gb1']}, {'seo': u'?hl=en&tab=w8', 'text': u'Play', u'href': u'https://play.google.com/?hl=en&tab=w8', u'class': [u'gb1']}],
+    "exclude_links": 12,
+    "duplicate_links": 20
 }, {
     "url": "http://www.freep.com/section/NLETTER10",
     "num_links": 144,
     "limit_find": [{'seo': u'm.freep.com', 'text': u'click here', u'style': u'color:#D19D4E;', u'href': u'http://m.freep.com'}, {'seo': u'%%=RedirectTo(@fullurl1)=%%', 'text': u'click here', u'style': u'color:#D19D4E;', u'href': u'%%=RedirectTo(@fullurl1)=%%', u'target': u'_blank'}, {'seo': u'www.freep.com', 'text': u'www.freep.com', u'href': u'http://www.freep.com'}, {'seo': u'facebook', 'text': u'facebook', u'href': u'http://www.freep.com/facebook'}, {'seo': u'twitter', 'text': u'twitter', u'href': u'http://www.freep.com/twitter'}],
     "limit_reverse_find": [{'href': 'http://www.freep.com/section/privacy#adchoices', 'seo': 'privacy#adchoices', 'text': 'Ad Choices', 'style': 'color:#4795CC;', 'target': '_blank'}, {'href': 'http://www.freep.com/section/privacy', 'seo': 'privacy', 'text': 'Privacy Notice/Your California Privacy Rights', 'style': 'color:#4795CC;', 'target': '_blank'}, {'href': 'http://www.freep.com/terms', 'seo': 'terms', 'text': 'Terms of Service', 'style': 'color:#4795CC;', 'target': '_blank'}, {'href': 'http://www.freep.com/section/subscription-options&gps-source=CPNLETSUB3', 'seo': 'subscription options&gps source=CPNLETSUB3', 'text': 'Subscribe to the Paper', 'style': 'color:#4795CC;', 'target': '_blank'}, {'href': '%%=RedirectTo(@fullurl)=%%', 'seo': '%%=RedirectTo(@fullurl)=%%', 'text': 'Unsubscribe to electronic mail', 'style': 'color:#4795CC;', 'target': '_blank'}],
     "limit_sort_text": [{'seo': u'm.freep.com', 'text': u'click here', u'style': u'color:#D19D4E;', u'href': u'http://m.freep.com'}, {'seo': u'%%=RedirectTo(@fullurl1)=%%', 'text': u'click here', u'style': u'color:#D19D4E;', u'href': u'%%=RedirectTo(@fullurl1)=%%', u'target': u'_blank'}, {'seo': u'facebook', 'text': u'facebook', u'href': u'http://www.freep.com/facebook'}, {'seo': u'twitter', 'text': u'twitter', u'href': u'http://www.freep.com/twitter'}, {'seo': u'www.freep.com', 'text': u'www.freep.com', u'href': u'http://www.freep.com'}],
-    "limit_sort_href": [{'seo': u'%%=RedirectTo(@fullurl1)=%%', 'text': u'click here', u'style': u'color:#D19D4E;', u'href': u'%%=RedirectTo(@fullurl1)=%%', u'target': u'_blank'}, {'seo': u'm.freep.com', 'text': u'click here', u'style': u'color:#D19D4E;', u'href': u'http://m.freep.com'}, {'seo': u'www.freep.com', 'text': u'www.freep.com', u'href': u'http://www.freep.com'}, {'seo': u'facebook', 'text': u'facebook', u'href': u'http://www.freep.com/facebook'}, {'seo': u'twitter', 'text': u'twitter', u'href': u'http://www.freep.com/twitter'}]
+    "limit_sort_href": [{'seo': u'%%=RedirectTo(@fullurl1)=%%', 'text': u'click here', u'style': u'color:#D19D4E;', u'href': u'%%=RedirectTo(@fullurl1)=%%', u'target': u'_blank'}, {'seo': u'm.freep.com', 'text': u'click here', u'style': u'color:#D19D4E;', u'href': u'http://m.freep.com'}, {'seo': u'www.freep.com', 'text': u'www.freep.com', u'href': u'http://www.freep.com'}, {'seo': u'facebook', 'text': u'facebook', u'href': u'http://www.freep.com/facebook'}, {'seo': u'twitter', 'text': u'twitter', u'href': u'http://www.freep.com/twitter'}],
+    "exclude_links": 144,
+    "duplicate_links": 93
 }]
